# Copyright (C) 2021-2023 Cochise Ruhulessin
#
# All rights reserved. No warranty, explicit or implicit, provided. In
# no event shall the author(s) be liable for any claim or damages.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
import pydantic

from .productinventorytype import ProductInventoryType


class BaseProductType(pydantic.BaseModel):
    display_name: str = pydantic.Field(
        default=...,
        title="Display name",
        alias='displayName',
        description=(
            "The human-readable name for this product type."
        )
    )

    inventory_type: ProductInventoryType = pydantic.Field(
        default=...,
        title="Inventory type",
        alias='inventoryType',
        description="Specifies the inventory type of the product."
    )

    is_final: bool = pydantic.Field(
        default=False,
        title="Is final?",
        alias='isFinal',
        description="Indicates if the product type is final and can not be subtyped."
    )